import request, { postBlob, getBlob, handleImport } from '@/utils/request'

export function comListDownloadGet(params) {
  return request({
    url: '/com/list/download/get',
    method: 'get',
    params
  })
}

export function adminWebsitPayConfigList(params) {
  return request({
    url: '/admin/websit/pay/config/list',
    method: 'post',
    params
  })
}

//高德省市区街道
export function lbsAmapRegion(params) {
  return request({
    url: '/common/region/list',
    method: 'get',
    params
  })
}

export function bigGetLarge1(params) {
  return request({
    url: '/big/getLarge1',
    method: 'post',
    params
  })
}

export function bigGetLarge11(params) {
  return request({
    url: '/big/getLarge11',
    method: 'get',
    params
  })
}

export function bigList(params) {
  return request({
    url: '/big/list',
    method: 'get',
    params
  })
}

export function bigGetLarge10(params) {
  return request({
    url: '/big/getLarge10',
    method: 'get',
    params
  })
}

export function bigGetLarge3(params) {
  return request({
    url: '/big/getLarge3',
    method: 'post',
    params
  })
}

export function bigGetLarge2(params) {
  return request({
    url: '/big/getLarge2',
    method: 'post',
    params
  })
}

export function bigGetLarge9(params) {
  return request({
    url: '/big/getLarge9',
    method: 'post',
    params
  })
}

export function commonCompanywechatGet(params) {
  return request({
    url: '/common/companywechat/get',
    method: 'post',
    params
  })
}

export function bigWaterGet(params) {
  return request({
    url: '/big/water/get',
    method: 'get',
    params
  })
}

export function bigGetRegion(params) {
  return request({
    url: '/big/getRegion',
    method: 'post',
    params
  })
}

// 模板下载
export function commonTemplateDownload(params, name) {
  return getBlob({
    url: 'common/template/download',
    params,
    name
  })
}

export function getSystemList(params) {
  return request({
    url: '/sys/dict/list/page',
    method: 'get',
    params
  })
}

export function getExpress(params) {
  return request({
    url: '/common/express',
    method: 'get',
    params
  })
}

export function getCompanyList(params) {
  return request({
    url: '/common/express/company',
    method: 'get',
    params
  })
}

// 获取oss配置
export function getOssConfig(params) {
  return request({
    url: '/common/oss/config',
    method: 'get',
    params
  })
}
